@@ -7,15 +7,14 @@ require Exporter;
 @ISA = (Exporter);
 @EXPORT = qw(expand unexpand $tabstop);
 
-use vars qw($VERSION $SUBVERSION $tabstop $debug);
-$VERSION = '2021.0722';
+use vars qw($VERSION $SUBVERSION $tabstop);
+$VERSION = '2021.0723';
 $SUBVERSION = 'modern'; # back-compat vestige
 
 use strict;
 
 BEGIN	{
 	$tabstop = 8;
-	$debug = 0;
 }
 
 sub expand {
@@ -60,11 +59,6 @@ sub unexpand
 			$lastbit = "\t"
 				if $lastbit eq $ts_as_space;
 			for $_ (@e) {
-				if ($debug) {
-					my $x = $_;
-					$x =~ s/\t/^I\t/gs;
-					print "sub on '$x'\n";
-				}
 				s/  +$/\t/;
 			}
 			$line = join('',@e, $lastbit);
