@@ -9,15 +9,14 @@ require Exporter;
 @EXPORT = qw(wrap fill);
 @EXPORT_OK = qw($columns $break $huge);
 
-$VERSION = '2021.0722';
+$VERSION = '2021.0723';
 $SUBVERSION = 'modern'; # back-compat vestige
 
-use vars qw($VERSION $SUBVERSION $columns $debug $break $huge $unexpand $tabstop $separator $separator2);
+use vars qw($VERSION $SUBVERSION $columns $break $huge $unexpand $tabstop $separator $separator2);
 use strict;
 
 BEGIN	{
 	$columns = 76;  # <= screen width
-	$debug = 0;
 	$break = '(?=\s)(?:\r\n|\PM\pM*)';
 	$huge = 'wrap'; # alternatively: 'die' or 'overflow'
 	$unexpand = 1;
@@ -90,17 +89,9 @@ sub wrap
 	}
 	$r .= $remainder;
 
-	print "-----------$r---------\n" if $debug;
-
-	print "Finish up with '$lead'\n" if $debug;
-
-	my($opos) = pos($t);
-
 	$r .= $lead . substr($t, pos($t), length($t) - pos($t))
 		if pos($t) ne length($t);
 
-	print "-----------$r---------\n" if $debug;;
-
 	return $r;
 }
 
